ERPNextAPI class

This class will be used for connecting the ERPNext instance using the API calls

Constructors

ERPNextAPI(String baseUrl, BuildContext context)

Properties

baseUrl String
getter/setter pair
context BuildContext
getter/setter pair
cookieHeader String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUri(String url, [Map<String, Object>? queryParameters]) Uri
This function is for getting the URI
getAllCompanies(Function callBack) Future<void>
This function is for getting all the companies attached to an user
getCompanyBS(String companyName, String fiscalYear, Function callBack) Future<void>
This function is for getting the Balance Sheet for a given company
getCompanyCOA(String companyName, Function callBack) Future<void>
This function is for getting the Chart Of Accounts for a given company
getCompanyDetails(String companyName, Function callBack) Future<void>
This function is for getting additional company details for a given company
getCompanyFY(String companyName, Function callBack) Future<void>
This function is for getting the Fiscal Years for a given company
getCompanyPL(String companyName, String fiscalYear, Function callBack) Future<void>
This function if for getting the Profit and Loss for a given company
getCompanyTB(String companyName, String fiscalYear, Function callBack) Future<void>
This function is for getting the Trial Balance for a given company
login(String userName, String password, Function callback) Future<void>
This function is for logging into the ERPNext instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited