AssetsModel class

This class handles asset data

Constructors

AssetsModel(String name, String asset_name, String status, String location, String asset_category)
AssetsModel.fromJson(Map<String, dynamic> json)
factory

Properties

asset_category String
getter/setter pair
asset_name String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited