BOMModel class

This class handles BOM data

Constructors

BOMModel(String name, String item, double quantity, String uom)
BOMModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
item String
getter/setter pair
name String
getter/setter pair
quantity double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uom String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited