CampaignModel class
This class handles campaign data
Constructors
- CampaignModel(String name, String campaign_name, String description)
-
CampaignModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- campaign_name ↔ String
-
getter/setter pair
- description ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited