CustomerModel class

This class handles customer data

Constructors

CustomerModel(String name, String customer_name, String customer_type, String? customer_group, String? gstin)
CustomerModel.fromJson(Map<String, dynamic> json)
factory

Properties

customer_group String?
getter/setter pair
customer_name String
getter/setter pair
customer_type String
getter/setter pair
gstin String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited