IssueModel class

This class handles issues data

Constructors

IssueModel(String name, String subject, String status, String raised_by, String priority, String issue_type, String customer)
IssueModel.fromJson(Map<String, dynamic> json)
factory

Properties

customer String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issue_type String
getter/setter pair
name String
getter/setter pair
priority String
getter/setter pair
raised_by String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
subject String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited