ItemModel class

This class handles item data

Constructors

ItemModel(String name, String item_code, String item_name, String description, String stock_uom, double opening_stock)
ItemModel.fromJson(Map<String, dynamic> json)
factory

Properties

description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
item_code String
getter/setter pair
item_name String
getter/setter pair
name String
getter/setter pair
opening_stock double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stock_uom String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited