LeadModel class

This class handles leads data

Constructors

LeadModel(String name, String lead_name, String status, String company_name, String type)
LeadModel.fromJson(Map<String, dynamic> json)
factory

Properties

company_name String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lead_name String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited