MaintenanceVisitModel class

This class handles maintenance visit data

Constructors

MaintenanceVisitModel(String name, String customer, String mntc_date, String maintenance_type, String completion_status, String status, String item_code, String service_person, String work_done)
MaintenanceVisitModel.fromJson(Map<String, dynamic> json)
factory

Properties

completion_status String
getter/setter pair
customer String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
item_code String
getter/setter pair
maintenance_type String
getter/setter pair
mntc_date String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service_person String
getter/setter pair
status String
getter/setter pair
work_done String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited