OpportunityModel class
This class handles opportunity data
Constructors
- OpportunityModel(String name, String opportunity_from, String status, String opportunity_type, String party_name)
-
OpportunityModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- opportunity_from ↔ String
-
getter/setter pair
- opportunity_type ↔ String
-
getter/setter pair
- party_name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited