ProjectModel class

This class handles projects data

Constructors

ProjectModel(String name, String project_name, String status, String expected_start_date, String expected_end_date)
ProjectModel.fromJson(Map<String, dynamic> json)
factory

Properties

expected_end_date String
getter/setter pair
expected_start_date String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
project_name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited