PurchaseInvoiceModel class

This class handles purchase invoice data

Constructors

PurchaseInvoiceModel(String name, String supplier, String posting_date, String status, double total)
PurchaseInvoiceModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
posting_date String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
supplier String
getter/setter pair
total double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited