QualityGoalModel class

This class handles quality goal data

Constructors

QualityGoalModel(String name, String frequency, String procedure, String objective, String target, String uom)
QualityGoalModel.fromJson(Map<String, dynamic> json)
factory

Properties

frequency String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
objective String
getter/setter pair
procedure String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String
getter/setter pair
uom String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited