QualityProcedureModel class

This class handles quality procedure data

Constructors

QualityProcedureModel(String name, String quality_procedure_name, String process_owner, String process_description)
QualityProcedureModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
process_description String
getter/setter pair
process_owner String
getter/setter pair
quality_procedure_name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited