QualityReviewModel class

This class handles quality review data

Constructors

QualityReviewModel(String name, String goal, String status, String objective, String review)
QualityReviewModel.fromJson(Map<String, dynamic> json)
factory

Properties

goal String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
objective String
getter/setter pair
review String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited