SupplierModel class

This class handles supplier data

Constructors

SupplierModel(String name, String supplier_name, String supplier_type, String? supplier_group, String? gstin)
SupplierModel.fromJson(Map<String, dynamic> json)
factory

Properties

gstin String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supplier_group String?
getter/setter pair
supplier_name String
getter/setter pair
supplier_type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited