TaskModel class

This class handles task data

Constructors

TaskModel(String name, String subject, String status, String priority, String project)
TaskModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
priority String
getter/setter pair
project String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
subject String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited