TimesheetModel class

This class handles timesheet data

Constructors

TimesheetModel(String name, String employee, String status, String start_date, String end_date, double total_hours)
TimesheetModel.fromJson(Map<String, dynamic> json)
factory

Properties

employee String
getter/setter pair
end_date String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start_date String
getter/setter pair
status String
getter/setter pair
total_hours double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited