WarehouseModel class

This class handle warehouse data

Constructors

WarehouseModel(String name, String warehouse_name, String parent_warehouse, int is_group)
WarehouseModel.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
is_group int
getter/setter pair
name String
getter/setter pair
parent_warehouse String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warehouse_name String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited