WorkOrderModel class

This class handles work order data

Constructors

WorkOrderModel(String name, String production_item, String status, double qty, String bom_no, String planned_start_date)
WorkOrderModel.fromJson(Map<String, dynamic> json)
factory

Properties

bom_no String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
planned_start_date String
getter/setter pair
production_item String
getter/setter pair
qty double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited