DashboardWidgetState class
This widget is for showing the Dashboard
- Inheritance
-
- Object
- State<
DashboardWidget> - DashboardWidgetState
- Mixed-in types
Constructors
Properties
- accountingTabController ↔ TabController
-
getter/setter pair
-
assetMovement
↔ List<
AssetMovementModel> -
getter/setter pair
-
assets
↔ List<
AssetsModel> -
getter/setter pair
- assetsTabController ↔ TabController
-
getter/setter pair
-
boms
↔ List<
BOMModel> -
getter/setter pair
-
campaigns
↔ List<
CampaignModel> -
getter/setter pair
-
companyCoaDetails
↔ List<
COAItem> -
getter/setter pair
- companyDetails ↔ CompanyModel
-
getter/setter pair
- companyDetailsAvailable ↔ bool
-
getter/setter pair
- context → BuildContext
-
The location in the tree where this widget builds.
no setterinherited
- crmTabController ↔ TabController
-
getter/setter pair
-
customers
↔ List<
CustomerModel> -
getter/setter pair
- financialsTabWidget ↔ FinancialsTabWidget
-
getter/setter pair
- fiscalYears ↔ List
-
getter/setter pair
-
fixedAssetRegister
↔ List<
FixedAssetRegister> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
issues
↔ List<
IssueModel> -
getter/setter pair
-
itemPriceStock
↔ List<
ItemPriceStockModel> -
getter/setter pair
-
items
↔ List<
ItemModel> -
getter/setter pair
-
leads
↔ List<
LeadModel> -
getter/setter pair
-
maintenanceSchedules
↔ List<
MaintenanceScheduleModel> -
getter/setter pair
-
maintenanceVisits
↔ List<
MaintenanceVisitModel> -
getter/setter pair
- manufacturingTabController ↔ TabController
-
getter/setter pair
- mounted → bool
-
Whether this State object is currently in a tree.
no setterinherited
-
opportunities
↔ List<
OpportunityModel> -
getter/setter pair
- procurementTabController ↔ TabController
-
getter/setter pair
-
productionPlan
↔ List<
ProductionPlanModel> -
getter/setter pair
-
projects
↔ List<
ProjectModel> -
getter/setter pair
- projectTabController ↔ TabController
-
getter/setter pair
-
purchaseInvoices
↔ List<
PurchaseInvoiceModel> -
getter/setter pair
-
purchaseOrders
↔ List<
PurchaseOrderModel> -
getter/setter pair
-
qualityGoals
↔ List<
QualityGoalModel> -
getter/setter pair
-
qualityProcedures
↔ List<
QualityProcedureModel> -
getter/setter pair
-
qualityReviews
↔ List<
QualityReviewModel> -
getter/setter pair
- qualityTabController ↔ TabController
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
salesInvoices
↔ List<
SalesInvoiceModel> -
getter/setter pair
-
salesOrders
↔ List<
SalesOrderModel> -
getter/setter pair
- selectedCompany ↔ String
-
getter/setter pair
- sellingTabController ↔ TabController
-
getter/setter pair
- stockTabController ↔ TabController
-
getter/setter pair
-
suppliers
↔ List<
SupplierModel> -
getter/setter pair
- supportTabController ↔ TabController
-
getter/setter pair
-
tasks
↔ List<
TaskModel> -
getter/setter pair
-
timesheets
↔ List<
TimesheetModel> -
getter/setter pair
-
warehouses
↔ List<
WarehouseModel> -
getter/setter pair
- widget → DashboardWidget
-
The current configuration.
no setterinherited
-
workOrders
↔ List<
WorkOrderModel> -
getter/setter pair
Methods
-
activate(
) → void -
Called when this object is reinserted into the tree after having been
removed via deactivate.
inherited
-
assetMovementWidget(
) → Widget -
assetsWidget(
) → Widget -
bomWidget(
) → Widget -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
campaignsWidget(
) → Widget -
companyCoaDetailsWidget(
) → Widget -
companyDetailsWidget(
) → Widget -
createTicker(
TickerCallback onTick) → Ticker -
Creates a ticker with the given callback.
inherited
-
customerWidget(
) → Widget -
CustomExpansionTile(
String title, List< Widget> children, bool initialExpanded) → Widget -
deactivate(
) → void -
Called when this object is removed from the tree.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
didChangeDependencies(
) → void -
Called when a dependency of this State object changes.
inherited
-
didUpdateWidget(
covariant DashboardWidget oldWidget) → void -
Called whenever the widget configuration changes.
inherited
-
dispose(
) → void -
Called when this object is removed from the tree permanently.
inherited
-
fixedAssetRegisterWidget(
) → Widget -
initState(
) → void -
Called when this object is inserted into the tree.
override
-
issuesWidget(
) → Widget -
itemPriceStockWidget(
) → Widget -
itemsWidget(
) → Widget -
leadsWidget(
) → Widget -
maintenanceSchedulesWidget(
) → Widget -
maintenanceVisitsWidget(
) → Widget -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
opportunitiesWidget(
) → Widget -
productionPlanWidget(
) → Widget -
projectsWidget(
) → Widget -
purchaseInvoicesWidget(
) → Widget -
purchaseOrdersWidget(
) → Widget -
qualityGoalsWidget(
) → Widget -
qualityProceduresWidget(
) → Widget -
qualityReviewsWidget(
) → Widget -
reassemble(
) → void -
Called whenever the application is reassembled during debugging, for
example during hot reload.
inherited
-
salesInvoicesWidget(
) → Widget -
salesOrdersWidget(
) → Widget -
setState(
VoidCallback fn) → void -
Notify the framework that the internal state of this object has changed.
inherited
-
showData(
) → void -
supplierWidget(
) → Widget -
tasksWidget(
) → Widget -
timesheetWidget(
) → Widget -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringShort(
) → String -
A brief description of this object, usually just the runtimeType and the
hashCode.
inherited
-
warehouseWidget(
) → Widget -
workOrderWidget(
) → Widget
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited