AssetMovementModel class
This class handle asset movement data
Constructors
- AssetMovementModel(String name, String purpose, String transaction_date, String asset_name, String source_location, String target_location)
-
AssetMovementModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- asset_name ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- purpose ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source_location ↔ String
-
getter/setter pair
- target_location ↔ String
-
getter/setter pair
- transaction_date ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited