MaintenanceScheduleModel class
This class handles maintenance schedule data
Constructors
Properties
- completion_status ↔ String
-
getter/setter pair
- end_date ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- item_code ↔ String
-
getter/setter pair
- name ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduled_date ↔ String
-
getter/setter pair
- start_date ↔ String
-
getter/setter pair
- status ↔ String
-
getter/setter pair
- transaction_date ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited